@@ -5,16 +5,9 @@ import os
 from pathlib import Path
 from metaflow.metaflow_config import AERO_ID_TOKEN, AERO_IDENTITY_POOL, AERO_PROVIDER
 
-
-def create_client_credentials():
+def get_credentials():
     import boto3
 
-    # Catch if running on Batch
-    if 'METAFLOW_INPUT_PATHS_0' in os.environ or 'MANAGED_BY_AWS' in os.environ:
-        return boto3.session.Session(
-            region_name='eu-west-1'
-        )
-
     client = boto3.client('cognito-identity', region_name='eu-west-1')
 
     try:
@@ -33,21 +26,46 @@ def create_client_credentials():
     secret_key = resp['Credentials']['SecretKey']
     access_key = resp['Credentials']['AccessKeyId']
     session_token = resp['Credentials']['SessionToken']
+    expiry = resp['Credentials']['Expiration']
 
-    session = boto3.session.Session(
-        aws_access_key_id=access_key,
-        aws_secret_access_key=secret_key,
-        aws_session_token=session_token,
+    return {
+        "access_key": access_key,
+        "secret_key": secret_key,
+        "token": session_token,
+        "expiry_time": expiry.isoformat()
+    }
+
+def create_client_credentials():
+    import boto3
+    from botocore.credentials import RefreshableCredentials
+    from botocore.session import get_session
+
+    # Catch if running on Batch
+    if 'METAFLOW_INPUT_PATHS_0' in os.environ or 'MANAGED_BY_AWS' in os.environ:
+        return boto3.session.Session(
+            region_name='eu-west-1'
+        )
+
+    session_credentials = RefreshableCredentials.create_from_metadata(
+        metadata = get_credentials(),
+        refresh_using = get_credentials,
+        method = 'sts-assume-role'
+    )
+
+    session = get_session()
+    session._credentials = session_credentials
+    autorefresh_session = boto3.Session(
+        botocore_session=session,
         region_name='eu-west-1'
     )
 
     try:
-        sts = session.client('sts')
+        sts = autorefresh_session.client('sts')
         sts.get_caller_identity()
     except:
         raise Exception("Credentials have expired, please run 'aero account login' again")
 
-    return session
+    return autorefresh_session
 
 AWS_SESSION = create_client_credentials()
 
