@@ -323,9 +323,9 @@ class Batch(object):
                     time.sleep(60)
                 
                     if requested_cpu + current_vcpus > cpu_limit:
-                        echo(f"New job of {pre_job.cpu} would push CPU usage to {pre_job.cpu + current_vcpus}, which is higher than the limit of {cpu_limit}")
+                        echo(f"New job of {requested_cpu} would push CPU usage to {requested_cpu + current_vcpus}, which is higher than the limit of {cpu_limit}")
                     else:
-                        echo(f"Requesting {pre_job.cpu} vcpus, current usage now {pre_job.cpu + current_vcpus}")
+                        echo(f"Requesting {requested_cpu} vcpus, current usage now {requested_cpu + current_vcpus}")
                         job_blocked = False
 
         def wait_for_launch(job):
